==> javathrottle-0.3.tar.gz: javathrottle-0.3/src/net/f00f/javathrottle/JWindowSelect.java <==
package net.f00f.javathrottle;

import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.event.EventListenerList;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.IOException;

import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

import javax.swing.*;

public class JWindowSelect extends JPanel
implements ActionListener
{
	private NewWindowEvent windowEvent = null;

	private JIntegerField numberField;
	//private JComboBox timeUnit;

	int numWindowEvents;
	ActionEvent rateEvent;

	public JWindowSelect( int def )
	{
		setLayout( new FlowLayout( FlowLayout.LEFT ) );
		numberField = new JIntegerField(def/1000, 8);

		add( numberField );
		add( new JLabel( " seconds" ) );
		add( Box.createGlue() );
		//add( timeUnit );
		JButton setButton = new JButton( "Set" );
		setButton.addActionListener( this );
		add( setButton );
	}

	EventListenerList listenerList = new EventListenerList();

	public void addActionListener(ActionListener l)
	{
		listenerList.add( ActionListener.class, l );
	}

	public void removeActionListener(ActionListener l)
	{
		listenerList.remove( ActionListener.class, l );
	}

	private void log(String msg)
	{
		Main.debug( msg );
	}

	public void actionPerformed( ActionEvent ae )
	{
		int window = numberField.getValue();

		fireActionEvent(window);
	}

	// Notify all listeners that have registered interest for
	// notification on this event type.  The event instance 
	// is lazily created using the parameters passed into 
	// the fire method.

	protected void fireActionEvent(int newWindow) {
		// Guaranteed to return a non-null array
		Object[] listeners = listenerList.getListenerList();
		// Process the listeners last to first, notifying
		// those that are interested in this event
		for (int i = listeners.length-2; i>=0; i-=2) {
			if (listeners[i] == ActionListener.class) {
				// Lazily create the event:
				if (windowEvent == null)
					windowEvent = new NewWindowEvent(this,++numWindowEvents,newWindow*1000 );
				((ActionListener)listeners[i+1]).actionPerformed( windowEvent );
			}
		}

		windowEvent = null;
	}
}

==> javathrottle-0.4.tar.gz: javathrottle-0.4/src/net/f00f/javathrottle/JWindowSelect.java <==
package net.f00f.javathrottle;

import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.event.EventListenerList;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.IOException;

import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

import javax.swing.*;

public class JWindowSelect extends JPanel
implements ActionListener
{
	private NewWindowEvent windowEvent = null;

	private JButton setButton;
	private JIntegerField numberField;
	private JLabel secondsLbl;

	//private JComboBox timeUnit;

	private int numWindowEvents;
	private ActionEvent rateEvent;

	public JWindowSelect( int def )
	{
		setLayout( new FlowLayout( FlowLayout.LEFT ) );
		numberField = new JIntegerField(def/1000, 8);

		add( numberField );
		add( secondsLbl = new JLabel( " seconds" ) );
		add( Box.createGlue() );
		//add( timeUnit );
		setButton = Main.makeSetButton();
		setButton.addActionListener( this );
		add( setButton );
	}

	public void setEnabled( boolean value )
	{
		super.setEnabled( value );
		numberField.setEnabled( value );
		secondsLbl.setEnabled( value );
		setButton.setEnabled( value );
	}

	public void setWindow( int newW )
	{
		numberField.setValue( newW );
	}

	EventListenerList listenerList = new EventListenerList();

	public void addActionListener(ActionListener l)
	{
		listenerList.add( ActionListener.class, l );
		// Trigger a declaration for the new listener
		actionPerformed( null );
	}

	public void removeActionListener(ActionListener l)
	{
		listenerList.remove( ActionListener.class, l );
	}

	private void log(String msg)
	{
		Main.debug( msg );
	}

	public void actionPerformed( ActionEvent ae )
	{
		int window = numberField.getValue();

		fireActionEvent(window);
	}

	// Notify all listeners that have registered interest for
	// notification on this event type.  The event instance 
	// is lazily created using the parameters passed into 
	// the fire method.

	protected void fireActionEvent(int newWindow) {
		// Guaranteed to return a non-null array
		Object[] listeners = listenerList.getListenerList();
		// Process the listeners last to first, notifying
		// those that are interested in this event
		for (int i = listeners.length-2; i>=0; i-=2) {
			if (listeners[i] == ActionListener.class) {
				// Lazily create the event:
				if (windowEvent == null)
					windowEvent = new NewWindowEvent(this,++numWindowEvents,newWindow*1000 );
				((ActionListener)listeners[i+1]).actionPerformed( windowEvent );
			}
		}

		windowEvent = null;
	}
}
